==> italc_1.0.7.orig.tar.gz: italc-1.0.7/lib/resources/it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="it_IT">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/local_system.cpp" line="51"/>
        <source>UPL (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</source>
        <translation>NPC (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</translation>
    </message>
    <message>
        <location filename="../src/local_system.cpp" line="704"/>
        <source>iTALC-snapshots</source>
        <translation type="unfinished">iTALC-foto</translation>
    </message>
</context>
<context>
    <name>ivsConnection</name>
    <message>
        <location filename="../src/ivs_connection.cpp" line="307"/>
        <source>Snapshot</source>
        <translation>Foto</translation>
    </message>
    <message>
        <location filename="../src/ivs_connection.cpp" line="309"/>
        <source>Could not take a snapshot as directory %1 doesn&apos;t exist and couldn&apos;t be created.</source>
        <translation>Non è possibile scattare una foto perché la cartella %1 non esiste e non è possibile crearla.</translation>
    </message>
</context>
<context>
    <name>localSystem::QObject</name>
    <message>
        <location filename="../src/local_system.cpp" line="692"/>
        <source>iTALC-snapshots</source>
        <translation type="obsolete">iTALC-foto</translation>
    </message>
</context>
<context>
    <name>lockWidget</name>
    <message>
        <location filename="../src/lock_widget.cpp" line="57"/>
        <source>screen lock</source>
        <translation>Schermo Bloccato</translation>
    </message>
</context>
<context>
    <name>messageBox</name>
    <message>
        <location filename="../src/messagebox.cpp" line="75"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>vncView</name>
    <message>
        <location filename="../src/vncview.cpp" line="55"/>
        <source>Establishing connection to %1 ...</source>
        <translation>Connessione con %1 ...</translation>
    </message>
</context>
</TS>

==> italc_1.0.9.orig.tar.gz: italc-1.0.9/lib/resources/it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="it_IT">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/local_system.cpp" line="52"/>
        <source>UPL (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</source>
        <translation>NPC (note for translators: the first three characters of this string are the accellerators (underlined characters) of the three input-fields in logon-dialog of windows - please keep this note as otherwise there are strange errors concerning logon-feature)</translation>
    </message>
    <message>
        <location filename="../src/local_system.cpp" line="642"/>
        <source>iTALC-snapshots</source>
        <translation>iTALC-foto</translation>
    </message>
</context>
<context>
    <name>ivsConnection</name>
    <message>
        <location filename="../src/ivs_connection.cpp" line="308"/>
        <source>Snapshot</source>
        <translation>Foto</translation>
    </message>
    <message>
        <location filename="../src/ivs_connection.cpp" line="310"/>
        <source>Could not take a snapshot as directory %1 doesn&apos;t exist and couldn&apos;t be created.</source>
        <translation>Non è possibile scattare una foto perché la cartella %1 non esiste e non è possibile crearla.</translation>
    </message>
</context>
<context>
    <name>localSystem::QObject</name>
    <message>
        <location filename="../src/local_system.cpp" line="692"/>
        <source>iTALC-snapshots</source>
        <translation type="obsolete">iTALC-foto</translation>
    </message>
</context>
<context>
    <name>lockWidget</name>
    <message>
        <location filename="../src/lock_widget.cpp" line="69"/>
        <source>screen lock</source>
        <translation>Schermo Bloccato</translation>
    </message>
</context>
<context>
    <name>messageBox</name>
    <message>
        <location filename="../src/messagebox.cpp" line="76"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>vncView</name>
    <message>
        <location filename="../src/vncview.cpp" line="61"/>
        <source>Establishing connection to %1 ...</source>
        <translation>Connessione con %1 ...</translation>
    </message>
</context>
</TS>
